@@ -408,9 +408,11 @@ class AddPresetAction(flow.Action):
     preset_name          = flow.Param('').ui(label='Name')
     task_name            = flow.Param('')
     path_template        = flow.Param('')
+    target_name          = flow.Param('')
     with flow.group('Optional'):
         optional_init    = flow.Param().ui(editor='bool').ui(label='When init')
         optional_new_rev = flow.Param().ui(editor='bool').ui(label='When new revision')
+    no_track             = flow.BoolParam()
 
     _map = flow.Parent()
 
@@ -422,10 +424,12 @@ class AddPresetAction(flow.Action):
             return
         
         p = self._map.add(self.preset_name.get())
-        p.path_template.set(self.path_template.get())
         p.task_name.set(self.task_name.get())
+        p.path_template.set(self.path_template.get())
+        p.target_name.set(self.target_name.get())
         p.optional_init.set(self.optional_init.get())
         p.optional_new_rev.set(self.optional_new_rev.get())
+        p.no_track.set(self.no_track.get())
         self._map.touch()
         return self.get_result(close=True)
 
@@ -452,12 +456,15 @@ class FileSourcePresets(flow.Map):
 
 class FilesItem(flow.Object):
 
-    file_name           = flow.Param('')
-    file_format         = flow.Param('')
-    file_comment        = flow.Param('')
-    file_path           = flow.Param('')
-    file_target         = flow.Param('')
-    rev_version         = flow.Param('v001')
+    file_name            = flow.Param('')
+    file_format          = flow.Param('')
+    file_comment         = flow.Param('')
+    file_path            = flow.Param('')
+    file_target          = flow.Param('')
+    rev_version          = flow.Param('v001')
+    with flow.group('Optional'):
+        optional_init    = flow.BoolParam().ui(label='When init')
+        optional_new_rev = flow.BoolParam().ui(label='When new revision')
 
 
 class AddFileTest(flow.Action):
@@ -516,6 +523,7 @@ class ShotItem(flow.Object):
 
     shot_name           = flow.Param('')
     new_shot            = flow.BoolParam(False)
+    shot_status         = flow.Param('')
     files_map           = flow.Child(FilesMap)
 
 
@@ -523,6 +531,7 @@ class AddShotTest(flow.Action):
 
     shot_name           = flow.Param('')
     new_shot            = flow.BoolParam(False)
+    shot_status         = flow.Param('')
     
     shots_map           = flow.Parent()
 
@@ -539,6 +548,7 @@ class AddShotTest(flow.Action):
         item = self.shots_map.add(self.shot_name.get())
         item.shot_name.set(self.shot_name.get())
         item.new_shot.set(self.new_shot.get())
+        item.shot_status.set(self.shot_status.get())
 
         self.shots_map.touch()
         return self.get_result(close=True)
@@ -618,6 +628,7 @@ class ImportFiles(flow.Action):
 
         for path in paths:
             rev = None
+            status = None
             shot_files = []
             if os.path.isfile(path):
                 #region Check if plas file
@@ -675,6 +686,7 @@ class ImportFiles(flow.Action):
                 #region rtk status
                 if shot != 'Create':
                     if shot.tasks[preset.task_name.get()].files.has_mapped_name(target_name) == True:
+                        status = 'rtk'
                         rev = shot.tasks[preset.task_name.get()].files[target_name].get_head_revision()
                         if rev and file_name.endswith('_') == False or (file_name.endswith('_') == False and file_name[-3] != 't'):
                             if preset.optional_new_rev.get() == False:
@@ -687,12 +699,16 @@ class ImportFiles(flow.Action):
                 
                 #region init status
                     else:
+                        status = 'init'
                         if preset.optional_init.get() == False:
                             incorrect['files'].append({
                                 'name': '/'.join(path.split('/')[-2:]),
                                 'error': 'init'
                             })
                             continue
+                
+                if shot == 'Create':
+                    status = 'init'
                 #endregion
 
                 #endregion
@@ -712,7 +728,8 @@ class ImportFiles(flow.Action):
                 if find_shot == False:
                     valid.append({
                         'shot': shot_name,
-                        'status': shot,
+                        'obj': shot,
+                        'status': status,
                         'files': [{
                             'path': path,
                             'preset': preset,
@@ -895,6 +912,7 @@ class ImportFiles(flow.Action):
                         #region rtk status
                         if shot != 'Create':
                             if shot.tasks[preset.task_name.get()].files.has_mapped_name(target_name) == True:
+                                status = 'rtk'
                                 rev = shot.tasks[preset.task_name.get()].files[target_name].get_head_revision()
                                 if rev and file_name.endswith('_') == False or (file_name.endswith('_') == False and file_name[-3] != 't'):
                                     if preset.optional_new_rev.get() == False:
@@ -921,6 +939,7 @@ class ImportFiles(flow.Action):
 
                         #region init status
                             else:
+                                status = 'init'
                                 if file_name.endswith('_') or (file_name.endswith('_') and file_name[-3] == 't'):
                                     if preset.optional_init.get() == False:
                                         find_entry = False
@@ -944,6 +963,7 @@ class ImportFiles(flow.Action):
                                         continue
                         
                         if shot == 'Create':
+                            status = 'init'
                             if file_name.endswith('_') or (file_name.endswith('_') and file_name[-3] == 't'):
                                 if preset.optional_init.get() == False:
                                     find_entry = False
@@ -1032,7 +1052,8 @@ class ImportFiles(flow.Action):
 
                     valid.append({
                         'shot': dir_name,
-                        'status': shot,
+                        'obj': shot,
+                        'status': status,
                         'files': shot_files
                     })
                 else:
@@ -1055,9 +1076,11 @@ class ImportFiles(flow.Action):
             else:
                 shot = self.shots_map.add(i['shot'])
 
-            if i['status'] == 'Create':
+            if i['obj'] == 'Create':
                 shot.new_shot.set(True)
             
+            shot.shot_status.set(i['status'])
+            
             #Create files in shot
             for f in i['files']:
                 name = f['name'].replace('.', '_')
@@ -1073,6 +1096,10 @@ class ImportFiles(flow.Action):
                 f_item = shot.files_map.add(name)
                 f_item.file_name.set(f['name'])
 
+                if i['status'] == 'rtk':
+                    if '.' in f['name']:
+                        f_item.file_comment.set('Created from ' + f['name'])
+
                 root, ext = os.path.splitext(f['path'])
                 if ext:
                     f_item.file_format.set(ext)
@@ -1087,16 +1114,21 @@ class ImportFiles(flow.Action):
                 else:
                     f_item.file_target.set(target_name)
                 
-                if i['status'] == 'Create':
+                if i['obj'] == 'Create':
                     f_item.rev_version.set('v001')
                 else:
                     if '.' in target_name:
                         target_name = target_name.replace('.', '_')
-                    if i['status'].tasks[f['preset'].task_name.get()].files.has_mapped_name(target_name):
-                        rev = i['status'].tasks[f['preset'].task_name.get()].files[target_name].get_head_revision()
+                    if i['obj'].tasks[f['preset'].task_name.get()].files.has_mapped_name(target_name):
+                        rev = i['obj'].tasks[f['preset'].task_name.get()].files[target_name].get_head_revision()
                         ver = int(rev.name().replace('v', ''))
                         ver = 'v' + f'{(ver + 1):03}'
                         f_item.rev_version.set(ver)
+                
+                if f['preset'].optional_init.get() == True:
+                    f_item.optional_init.set(True)
+                if f['preset'].optional_new_rev.get() == True:
+                    f_item.optional_new_rev.set(True)
 
         # print('Incorrect files=> ', incorrect)
         # print('Valid shots=> ', valid)
