@@ -189,6 +189,7 @@ class ShotListItem(QtWidgets.QTreeWidgetItem):
         self.tree = tree
         self.custom_widget = tree.parent()
         self.shot = shot
+        self.status = self.custom_widget.session.cmds.Flow.get_value(self.shot + '/shot_status')
 
         self.refresh()
     
@@ -207,13 +208,13 @@ class ShotListItem(QtWidgets.QTreeWidgetItem):
         self.setExpanded(True)
         
         self.setText(0, shot_name)
-        if self.status() == True:
+        if self.new_shot() == True:
             self.setIcon(1, self.get_icon(('icons.gui', 'plus-black-symbol')))
             self.setToolTip(1, 'Shot will be created in libreflow')
         
         self.paint()
 
-    def status(self):
+    def new_shot(self):
         return self.custom_widget.session.cmds.Flow.get_value(self.shot + '/new_shot')
 
     def paint(self):
@@ -350,14 +351,26 @@ class ShotList(QtWidgets.QTreeWidget):
                 lambda checked=False, x=item: self._on_remove_all_files_action_clicked(x)
             )
         else:
-            remove_comment = context_menu.addAction(self.get_icon(('icons.gui', 'speech-bubbles-comment-option')), 'Remove Comment')
-            remove_file    = context_menu.addAction(self.get_icon(('icons.gui', 'remove-symbol')), 'Remove File')
-        
-            remove_comment.triggered.connect(
-                lambda checked=False, x=item: self._on_remove_comment_action_clicked(x)
-            )
-            remove_file.triggered.connect(
-                lambda checked=False, x=item: self._on_remove_file_action_clicked(x)
-            )
+            if item.toolTip(1) != '':
+                remove_comment = context_menu.addAction(self.get_icon(('icons.gui', 'speech-bubbles-comment-option')), 'Remove Comment')
+                remove_comment.triggered.connect(
+                    lambda checked=False, x=item: self._on_remove_comment_action_clicked(x)
+                )
 
-        context_menu.exec_(self.mapToGlobal(event))
\ No newline at end of file
+            if item.parent().status == 'init':
+                optional_init = self._custom_widget.session.cmds.Flow.get_value(item.shot_file + '/optional_init')
+                if optional_init == True:
+                    remove_file = context_menu.addAction(self.get_icon(('icons.gui', 'remove-symbol')), 'Remove File')
+                    remove_file.triggered.connect(
+                        lambda checked=False, x=item: self._on_remove_file_action_clicked(x)
+                    )
+            if item.parent().status == 'rtk':
+                optional_new_rev = self._custom_widget.session.cmds.Flow.get_value(item.shot_file + '/optional_new_rev')
+                if optional_new_rev == True:
+                    remove_file = context_menu.addAction(self.get_icon(('icons.gui', 'remove-symbol')), 'Remove File')
+                    remove_file.triggered.connect(
+                        lambda checked=False, x=item: self._on_remove_file_action_clicked(x)
+                    )
+
+        if context_menu.isEmpty() != True:
+            context_menu.exec_(self.mapToGlobal(event))
\ No newline at end of file
