@@ -241,6 +241,8 @@ class ShotToSendItem(QtWidgets.QTreeWidgetItem):
             if res == QtWidgets.QDialog.Accepted:
                 new_take = self._custom_widget.dialog_choose_take.get_new_take()
                 self.set_new_take(new_take)
+                self._get_checkbox_select().setCheckState(QtCore.Qt.Checked)
+                self.set_selected(True)
 
                 if new_take:
                     self.update_state(ShotState.NEW_TAKE_PACK_UNSELECTED)
